==> azure-cli_2.18.0.orig.tar.gz: azure-cli-azure-cli-2.18.0/src/azure-cli/azure/cli/command_modules/netappfiles/_client_factory.py <==
# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

# pylint: disable=unused-argument


def cf_netappfiles(cli_ctx, *kwargs):
    from azure.cli.core.commands.client_factory import get_mgmt_service_client
    from azure.mgmt.netapp import AzureNetAppFilesManagementClient
    return get_mgmt_service_client(cli_ctx, AzureNetAppFilesManagementClient)


def accounts_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).accounts


def pools_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).pools


def volumes_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).volumes


def snapshots_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).snapshots


def snapshot_policies_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).snapshot_policies


def account_backups_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).account_backups


def backups_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).backups


def backup_policies_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).backup_policies


def vaults_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).vaults

==> azure-cli_2.35.0.orig.tar.gz: azure-cli-azure-cli-2.35.0/src/azure-cli/azure/cli/command_modules/netappfiles/_client_factory.py <==
# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

# pylint: disable=unused-argument


def cf_netappfiles(cli_ctx, *kwargs):
    from azure.cli.core.commands.client_factory import get_mgmt_service_client
    from azure.mgmt.netapp import NetAppManagementClient
    return get_mgmt_service_client(cli_ctx, NetAppManagementClient)


def accounts_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).accounts


def pools_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).pools


def volumes_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).volumes


def snapshots_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).snapshots


def snapshot_policies_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).snapshot_policies


def account_backups_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).account_backups


def backups_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).backups


def backup_policies_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).backup_policies


def vaults_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).vaults


def subvolumes_mgmt_client_factory(cli_ctx, _):
    return cf_netappfiles(cli_ctx).subvolumes
